//
//  AppDelegate.swift
//  3DTouch
//
//

import UIKit

@UIApplicationMain
class AppDelegate: UIResponder, UIApplicationDelegate, UINavigationControllerDelegate,UIImagePickerControllerDelegate  {

    var window: UIWindow?


    func application(application: UIApplication, didFinishLaunchingWithOptions launchOptions: [NSObject: AnyObject]?) -> Bool {
        // Override point for customization after application launch.
        
        // クイックアクセスのメニューを生成
        let shortcut1 = UIApplicationShortcutItem(type: "Search",
            localizedTitle: "探す",
            localizedSubtitle: "検索はこちらから",
            icon: UIApplicationShortcutIcon(type: UIApplicationShortcutIconType.Search),
            userInfo: nil
        )
        
        // サブタイトルを指定しない場合
        let shortcut2 = UIApplicationShortcutItem(type: "CapturePhoto",
            localizedTitle: "写真撮影",
            localizedSubtitle: "",
            icon: UIApplicationShortcutIcon(type: UIApplicationShortcutIconType.CapturePhoto),
            userInfo: nil
        )
        
        // 画像を指定してアイコンを生成
        let icon = UIApplicationShortcutIcon(templateImageName: "earth.png")
        
        // 生成したアイコンを使ってメニューを生成
        let shortcut3 = UIApplicationShortcutItem(type: "Earth",
            localizedTitle: "世界の遺跡",
            localizedSubtitle: "展示会開催中です",
            icon: icon,
            userInfo: nil
        )
        
        // クイックメニューを指定
        application.shortcutItems = [shortcut1, shortcut2, shortcut3]

        // ウィンドウのサイズを指定
        self.window = UIWindow(frame: UIScreen.mainScreen().bounds)
        // ViewControllerを初期化
        let mainViewController = MainViewController(nibName : nil, bundle : nil)
        
        let myNavigationController = UINavigationController(rootViewController: mainViewController)
        
        // ルートビューコントローラーを指定
        self.window!.rootViewController = myNavigationController
        // ビューコントローラーの背景色を指定
        self.window!.backgroundColor = UIColor.whiteColor()
        // windowを表示
        self.window!.makeKeyAndVisible()
        return true
    }

    // クイックアクセスからの起動後の処理
    func application(application: UIApplication, performActionForShortcutItem shortcutItem: UIApplicationShortcutItem, completionHandler: Bool -> Void) {
        // クイックアクセスのメニュー別に処理を分ける
        switch (shortcutItem.type) {
            case "Search" :
                shortcutHandler(shortcutItem.localizedTitle)
            case "CapturePhoto" :
                // カメラを起動
                let picker : UIImagePickerController = UIImagePickerController()
                picker.sourceType = UIImagePickerControllerSourceType.Camera
                picker.allowsEditing = true
                picker.delegate = self
                self.window!.rootViewController!.presentViewController(picker, animated: true, completion: nil)
            case "Earth" :
                shortcutHandler(shortcutItem.localizedTitle)
            default:
                break
        }
        completionHandler(true)
    }
    
    // どのメニューから起動されたかをアラートで表示
    func shortcutHandler(title: String){
        
        let alertController = UIAlertController(
                                title: "クイックアクセスからの起動",
                                message: title,
                                preferredStyle: .Alert)
        let okAction = UIAlertAction(title: "OK",
                                        style: .Default,
                                        handler: nil)
        
        alertController.addAction(okAction)
        
        window!.rootViewController?.presentViewController(alertController,animated: true, completion: nil)
    }
    
    
    func applicationWillResignActive(application: UIApplication) {
        // Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
        // Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
    }

    func applicationDidEnterBackground(application: UIApplication) {
        // Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later.
        // If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
    }

    func applicationWillEnterForeground(application: UIApplication) {
        // Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
    }

    func applicationDidBecomeActive(application: UIApplication) {
        // Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
    }

    func applicationWillTerminate(application: UIApplication) {
        // Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
    }

}

