//
//  PeekViewController.swift
//  3DTouch
//
//

import UIKit
import MapKit

class PeekViewController: UIViewController {

    var mapView: MKMapView!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        // 中心の緯度経度
        let location = CLLocationCoordinate2D(
            latitude: 35.702811,
            longitude: 139.579804
        )
        // 地図の上端の緯度と下端の緯度の差
        // 地図の左端の経度と右端の経度の差
        let span = MKCoordinateSpanMake(0.01, 0.01)
        
        let region = MKCoordinateRegion(center: location, span: span)
        
        mapView = MKMapView(frame: self.view.frame)
        
        // 範囲を指定
        mapView.setRegion(region, animated: true)
        
        // MKAnnotationプロトコルを実装したクラスをコール
        let spot : Spot = Spot(title: "吉祥寺駅", subtitle: "世界一の電波塔", coordinate: location)
        // ピンを立てる
        mapView.addAnnotation(spot)
        
        self.view.addSubview(mapView)
    }

    override func previewActionItems() -> [UIPreviewActionItem] {
        
        let action1 : UIPreviewAction = UIPreviewAction(title: "Menu 1",
                                                        style: UIPreviewActionStyle.Default,
                                                        handler: { previewAction, viewController in
                                                                    print("Menu 1 が選択されました")
                                                        })
        
        let action2 : UIPreviewAction = UIPreviewAction(title: "Menu 2",
                                                        style: UIPreviewActionStyle.Selected,
                                                        handler: { previewAction, viewController in
                                                                    print("Menu 2 が選択されました")
        })
        
        let action3 : UIPreviewAction = UIPreviewAction(title: "Menu 3",
                                                        style: UIPreviewActionStyle.Destructive,
                                                        handler: { previewAction, viewController in
                                                                    print("Menu 3 が選択されました")
        })
        
        let groupAction1 : UIPreviewActionGroup = UIPreviewActionGroup(title: "Group Menu 1",
                                                    style: UIPreviewActionStyle.Default,
                                                    actions: [action1, action2])
        
        let groupAction2 : UIPreviewActionGroup = UIPreviewActionGroup(title: "Group Menu 2",
                                                    style: UIPreviewActionStyle.Default,
                                                    actions: [action2, action3])
        
        // メニューをUIPreviewActionGroupオブジェクトの配列で返す
        //return [action1, action2, action3]
        return [groupAction1, groupAction2]
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}

class Spot: NSObject,MKAnnotation {
    
    var coordinate: CLLocationCoordinate2D
    var title: String? = ""
    var subtitle: String? = ""
    
    // 初期化処理
    internal init(title: String, subtitle : String, coordinate: CLLocationCoordinate2D){
        self.coordinate = coordinate
        self.title = title
        self.subtitle = subtitle
    }
}

