//
//  MovieViewController.swift
//  Data
//
//

import UIKit
import MediaPlayer

class MovieViewController: UIViewController {
    
    var player : MPMoviePlayerController!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        let url: NSURL = NSBundle.mainBundle().URLForResource("sample", withExtension: "mov")!
    
        // 動画ファイルのURLを指定して初期化
        self.player = MPMoviePlayerController(contentURL: url)
        self.player.scalingMode = MPMovieScalingMode.AspectFit
        //self.player.controlStyle = MPMovieControlStyleEmbedded
        
        // サイズを指定して画面に表示
        self.player.view.frame = CGRectMake(60, 120, 240, 180)
        self.player.view.center = CGPointMake(self.view.bounds.size.width/2,self.view.bounds.size.height/2)
        self.view.addSubview(player.view)
    
    }
    
    // 再生ボタン
    @IBAction func play(sender: AnyObject) {
        self.player.play()
    }
    
    // 停止ボタン
    @IBAction func stop(sender: AnyObject) {
        self.player.stop()
    }
    
    // フルスクリーンボタン
    @IBAction func full(sender: AnyObject) {
        // フルスクリーンで再生
        self.player.fullscreen = true
        
        // 繰り返し指定
        self.player.repeatMode = MPMovieRepeatMode.One
        
        self.player.play()
    }
    
    @IBAction func thumb(sender: AnyObject) {
        // 動画からサムネイルの取得が完了した際に呼ぶメソッドを指定
        NSNotificationCenter.defaultCenter().addObserver(self,
            selector: "showThumbImage:",
            name: MPMoviePlayerThumbnailImageRequestDidFinishNotification,
            object: nil)
        
        // 3秒のところでサムネイルを取得
        self.player.requestThumbnailImagesAtTimes([3.0], timeOption: MPMovieTimeOption.NearestKeyFrame)
    }
    
    // 完了時に呼ばれるメソッド
    func showThumbImage(notification: NSNotification)
    {
        // NSNotificationオブジェクトからサムネイル画像を取得
        var theUserInfo : Dictionary = notification.userInfo!
        if let image : UIImage = theUserInfo[MPMoviePlayerThumbnailImageKey] as? UIImage{
            // プレイヤーの画面に表示
            let iv : UIImageView = UIImageView(image: image)
            iv.frame = CGRectMake(60, 120, 240,180)
            self.view.addSubview(iv)
        }
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
