//
//  CameraViewController.swift
//  Device
//
//

import UIKit
import MobileCoreServices

class CameraViewController: UIViewController, UIActionSheetDelegate, UINavigationControllerDelegate,UIImagePickerControllerDelegate {

    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
    }

    @IBAction func showPicker(sender: AnyObject) {
        
        var actionSheet = UIAlertController(title: "選択してください", message: nil, preferredStyle: .ActionSheet)
        func handler(act:UIAlertAction!) {
            
            // 種類を指定してピッカーを表示
            let picker : UIImagePickerController = UIImagePickerController()
            picker.sourceType = UIImagePickerControllerSourceType.Camera
            picker.allowsEditing = true
            picker.delegate = self
            // 背面のカメラを指定
            //picker.cameraDevice = UIImagePickerControllerCameraDevice.Rear
            
            // 写真撮影
            if(act.title == "写真撮影"){
                picker.mediaTypes = [kUTTypeImage as String]
                picker.cameraCaptureMode = UIImagePickerControllerCameraCaptureMode.Photo
            }
            // 動画撮影
            else{
                picker.mediaTypes = [kUTTypeMovie as String]
                picker.cameraCaptureMode = UIImagePickerControllerCameraCaptureMode.Video
                // 画質指定
                picker.videoQuality = UIImagePickerControllerQualityType.TypeHigh
                // 撮影時間の上限
                picker.videoMaximumDuration = 300
            }
            // 撮影した画像／映像を編集可能に
            picker.allowsEditing = true
            self.presentViewController(picker, animated: true, completion: nil)
        }
        
        actionSheet.addAction(UIAlertAction(title: "写真撮影", style: .Default, handler: handler))
        actionSheet.addAction(UIAlertAction(title: "動画撮影", style: .Default, handler: handler))
        actionSheet.addAction(UIAlertAction(title: "Cancel", style: .Cancel, handler: nil))
        self.presentViewController(actionSheet, animated: true, completion: nil)
        
    }
    
    
    // ピッカー終了時の処理
    func imagePickerController(picker: UIImagePickerController,
            didFinishPickingMediaWithInfo info: [String : AnyObject]){
        
        // メディアのタイプを取得
        let mediaType:AnyObject? = info[UIImagePickerControllerMediaType]
        
        // 画像の場合
        if String(stringInterpolationSegment: mediaType!) == kUTTypeImage as NSString as String{
            // 撮影した画像
            if let image : UIImage = info[UIImagePickerControllerOriginalImage] as? UIImage {
                // フォトアルバムに保存
                UIImageWriteToSavedPhotosAlbum(image, self, "image:didFinishSavingWithError:contextInfo:", nil)
            }
        }
        else
        // 動画の場合
        if String(stringInterpolationSegment: mediaType!) == kUTTypeMovie as NSString as String{
            // 撮影した動画のURL
            if let movieUrl : NSURL = info[UIImagePickerControllerMediaURL] as? NSURL{
                let moviePath = movieUrl.relativePath
                UISaveVideoAtPathToSavedPhotosAlbum(moviePath!, self,"video:didFinishSavingWithError:contextInfo:", nil)
            }
        }
        // ピッカーを閉じる
        picker.dismissViewControllerAnimated(true, completion: nil)
    }
    
    // 画像保存時のセレクタ
    func image(image: UIImage, didFinishSavingWithError error: NSError!, contextInfo: UnsafeMutablePointer<Void>) {
        
        var message : String?
        if error == nil {
            message = "保存しました"
        } else {
            message = "保存に失敗しました"
        }
        
        // 処理の完了時にはアラートを出す
        let alert = UIAlertController(title: message!, message: "", preferredStyle: .Alert)
        // OKボタンを追加
        let okAction = UIAlertAction(title: "OK", style: .Default, handler: nil)
        alert.addAction(okAction)
        // 表示
        presentViewController(alert, animated: true, completion: nil)
    }
    
    // 動画保存時のセレクタ
    func video( videoPath:NSString, didFinishSavingWithError error :NSError!, contextInfo: UnsafeMutablePointer<Void>){
            
            var message : String?
            if (error == nil) {
                message = "保存しました"
            } else {
                message = "保存に失敗しました"
            }
            
            // 処理の完了時にはアラートを出す
            let alert = UIAlertController(title: message!, message: "", preferredStyle: .Alert)
            // OKボタンを追加
            let okAction = UIAlertAction(title: "OK", style: .Default, handler: nil)
            alert.addAction(okAction)
            // 表示
            presentViewController(alert, animated: true, completion: nil)
    }
    
    func imagePickerControllerDidCancel(picker: UIImagePickerController) {
        // ピッカーを閉じる
        self.dismissViewControllerAnimated(true, completion: nil)
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
