//
//  ImagePickerViewController.swift
//  Device
//
//

import UIKit

class ImagePickerViewController: UIViewController , UIActionSheetDelegate, UINavigationControllerDelegate, UIImagePickerControllerDelegate {

    @IBOutlet var imageView: UIImageView!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
    }

    // アクションシートでイメージピッカーの種類を選択
    @IBAction func showPicker(sender: AnyObject) {
        
        // switch文
        let animal:String = "cat"
        switch animal{
        case "dog":
            print("犬です")
        case "cat":
            print("猫です")
        default:
            print("その他の動物です")
        }
        
        var actionSheet = UIAlertController(title: "選択してください", message: nil, preferredStyle: .ActionSheet)
        func handler(act:UIAlertAction!) {
            var sourceType : UIImagePickerControllerSourceType?
            switch (act.title!) {
                case "Camera":
                    // カメラで画像を取得
                    sourceType = UIImagePickerControllerSourceType.Camera
                case "Photo Album":
                    // フォトライブラリから画像を取得
                    sourceType = UIImagePickerControllerSourceType.PhotoLibrary
                case "Saved Photos":
                    // カメラで撮影した画像から取得
                    sourceType = UIImagePickerControllerSourceType.SavedPhotosAlbum
                default:
                    break
            }
            
            // 種類を指定してピッカーを表示
            let picker : UIImagePickerController = UIImagePickerController()
            picker.sourceType = sourceType!
            picker.allowsEditing = true
            picker.delegate = self
            
            // 種類を指定してピッカーを表示
            self.presentViewController(picker, animated: true, completion: nil)
        }
        
        actionSheet.addAction(UIAlertAction(title: "Camera", style: .Default, handler: handler))
        actionSheet.addAction(UIAlertAction(title: "Photo Album", style: .Default, handler: handler))
        actionSheet.addAction(UIAlertAction(title: "Saved Photos", style: .Default, handler: handler))
        actionSheet.addAction(UIAlertAction(title: "Cancel", style: .Cancel, handler: nil))
        self.presentViewController(actionSheet, animated: true, completion: nil)
    }
    
    @IBAction func savePhoto(sender: AnyObject) {
        if imageView.image == nil { return }
        // 画像データ取得
        if let image : UIImage = imageView.image{
            UIImageWriteToSavedPhotosAlbum(image, self, "image:didFinishSavingWithError:contextInfo:", nil)
        }
        
    }
    
    
    // 画像保存時のセレクタ
    func image(image: UIImage, didFinishSavingWithError error: NSError!, contextInfo: UnsafeMutablePointer<Void>) {
        
        var message : String?
        if (error == nil) {
            message = "保存しました"
        } else {
            message = "保存に失敗しました"
        }
        
        // 処理の完了時にはアラートを出す
        let alert = UIAlertController(title: message!, message: "", preferredStyle: .Alert)
        // OKボタンを追加
        let okAction = UIAlertAction(title: "OK", style: .Default, handler: nil)
        alert.addAction(okAction)
        // 表示
        presentViewController(alert, animated: true, completion: nil)
    }

    // 画像選択時の処理
    func imagePickerController(picker: UIImagePickerController,
        didFinishPickingMediaWithInfo info: [String : AnyObject]) {
        
        // 選択した画像を画面に表示
        if let image : UIImage = info[UIImagePickerControllerOriginalImage] as? UIImage{
            imageView.image  = image
        }
        // ピッカーを閉じる
        self.dismissViewControllerAnimated(true, completion: nil)
    }
    
    // キャンセル時の処理
    func imagePickerControllerDidCancel(picker: UIImagePickerController) {
        // ピッカーを閉じる
        self.dismissViewControllerAnimated(true, completion: nil)
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
