//
//  BackgroundViewController.swift
//  Net
//
//

import UIKit

class BackgroundViewController: UIViewController, NSURLSessionDelegate, NSURLSessionDownloadDelegate{

    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        
    }

    @IBAction func onBackGround(sender: AnyObject) {
        
        // URLを指定してNSURLオブジェクトを生成
        let str : String = "http://www.apple.com/education/docs/Apple_ID_Parent_Guide.pdf"
        let url : NSURL = NSURL(string: str)!
        
        let identifier : String = "sample"
        
        // 詳細を指定 バックグラウンド通信を利用
        let config : NSURLSessionConfiguration = NSURLSessionConfiguration.backgroundSessionConfigurationWithIdentifier(identifier)
        // キャリア回線を利用
        config.allowsCellularAccess = true
        // 状況に応じて優先度を下げる
        config.discretionary = true
        // NSURLSessionオブジェクトを生成
        let session = NSURLSession(configuration: config, delegate: self, delegateQueue: nil)
        
        let task : NSURLSessionDownloadTask = session.downloadTaskWithURL(url)
        // 通信を開始
        task.resume()
    }
    
    // ダウンロード中の処理
    func URLSession(session: NSURLSession,
        downloadTask: NSURLSessionDownloadTask,
        didWriteData bytesWritten: Int64,
        totalBytesWritten: Int64,
        totalBytesExpectedToWrite: Int64)
    {
        print(totalBytesExpectedToWrite)
        dispatch_async(dispatch_get_main_queue(), {
            // ダウンロードするトータルのサイズに対する現在ダウンロードしたサイズの割合
            let progress : Float = Float(totalBytesWritten)/Float(totalBytesExpectedToWrite)
            print(progress)
        })
    }
    
    
    // ダウンロード完了時の処理
    func URLSession(session: NSURLSession,
        downloadTask: NSURLSessionDownloadTask,
        didFinishDownloadingToURL location: NSURL)
    {
        // ダウンローしたデータを保存
        let filename: String = "sample.pdf"
        let manager = NSFileManager.defaultManager()
        let docURL = try! manager.URLForDirectory(.DocumentDirectory, inDomain:.UserDomainMask, appropriateForURL:nil, create:true)
        let filePathURL: NSURL = docURL.URLByAppendingPathComponent(filename)
        
        print(filePathURL)
        
        // ファイルがすでに存在する場合は削除
        do{
            try manager.removeItemAtURL(filePathURL)
        }catch{}
        // 保存
        do{
            try manager.moveItemAtURL(location, toURL: filePathURL)
        }catch{}
    }
    
    func URLSession(session: NSURLSession, task: NSURLSessionTask, didCompleteWithError error: NSError?) {
        
        // エラーがあれば出力
        if error != nil {
            print(error)
            return
        }
        // NSURLSessionを終了
        session.finishTasksAndInvalidate()
    }
    
    // バックグラウンドでのHTTP通信時の処理
    func URLSessionDidFinishEventsForBackgroundURLSession(session: NSURLSession)
    {
        // AppDelegateを取得
        let delegate : AppDelegate = UIApplication.sharedApplication().delegate as! AppDelegate
        // ハンドラを取得
        if (delegate.handler != nil) {
            var completionHandler:Void = delegate.handler
            delegate.handler = nil
        }
        print("バックグラウンドセッション終了")
    }
    
    
    func URLSession(session: NSURLSession,
        didReceiveChallenge challenge: NSURLAuthenticationChallenge,
        completionHandler: (NSURLSessionAuthChallengeDisposition,
        NSURLCredential?) -> Void)
    {
        print("バックグラウンド イベント終了")
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
