//
//  ViewController.swift
//  Pop
//
//

import UIKit

class ViewController: UIViewController, UIPopoverControllerDelegate,UISearchBarDelegate, ContentPopoverDelegate {
    
    var searchBar : UISearchBar!
    var barButton : UIBarButtonItem!
    var popover : UIPopoverController!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        
        // ポップオーバーを表示するボタンを定義
        self.barButton = UIBarButtonItem(title: "POP", style: UIBarButtonItemStyle.Plain, target: self, action:"showPop:")
        
        self.navigationItem.setRightBarButtonItem(self.barButton, animated: true)
        
        self.searchBar = UISearchBar()
        self.searchBar.delegate = self
        self.navigationItem.titleView = self.searchBar
        self.navigationItem.titleView!.frame = CGRectMake(0, 0, 320, 44)
        
        // ポップオーバー内に表示する画面
        let ct : ContentTableViewController = ContentTableViewController(nibName : nil, bundle : nil)
        ct.delegate = self;
        // 中に表示するビューコントローラーを指定してポップオーバーを生成
        popover = UIPopoverController(contentViewController: ct)
        popover.delegate = self
    }
    
    func searchBarTextDidBeginEditing(searchBar: UISearchBar)
    {
        // ポップオーバーが現在表示されていれば何もしない
        if popover.popoverVisible { return }
        
        // タップしても閉じないUIを指定
        popover.passthroughViews = [self.searchBar]
        // 検索窓にアンカーしてポップオーバーを表示
        popover.presentPopoverFromRect(self.searchBar.bounds, inView: self.searchBar, permittedArrowDirections: UIPopoverArrowDirection.Up, animated: true)
        
    }
    
    // ポタン押下時に実行されるメソッド
    func showPop(sender:UIBarButtonItem) {
        
        // ポップオーバーが現在表示されていれば何もしない
        if popover.popoverVisible { return }
        
        // ポップオーバー内に表示する画面
        let ct : ContentTableViewController = ContentTableViewController(nibName : nil, bundle : nil)
        ct.delegate = self;
        // 中に表示するビューコントローラーを指定してポップオーバーを生成
        popover = UIPopoverController(contentViewController: ct)
        popover.delegate = self
        
        // 240x180のサイズで表示する
        popover.popoverContentSize = CGSizeMake(240,180);
        
        // ポップオーバーを表示する
        popover.presentPopoverFromBarButtonItem(self.barButton, permittedArrowDirections: UIPopoverArrowDirection.Any, animated: true)
    }
    
    // デリゲートで定義されたメソッドを実装
    // ポップオーバーでの項目選択時の処理
    func didSelect(word:String)
    {
        // メニューの選択されたセルの文字列を表示
        self.searchBar.text = word;
        // ポップオーバーを閉じる
        if popover.popoverVisible { popover.dismissPopoverAnimated(true) }
    }
    
    
    func popoverControllerShouldDismissPopover(popoverController: UIPopoverController) -> Bool
    {
        return true
    }
    
    func popoverControllerDidDismissPopover(popoverController: UIPopoverController)
    {
        // 入力欄の内容を取得
        let text : String = self.searchBar!.text!
        print(text)
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
}

