//
//  DatePickerViewController.swift
//  UI
//
//

import UIKit

class DatePickerViewController: UIViewController {

    var datePicker : UIDatePicker?
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        let items : Array<String> = ["月日時分", "年月日", "時分", "タイマー"]
        
        let segment : UISegmentedControl = UISegmentedControl(items: items)
        
        segment.frame = CGRectMake(10, 80, 300, 30)
        segment.tintColor = UIColor.grayColor()
        segment.momentary = true
        
        self.view.addSubview(segment)
        
        segment.addTarget(self, action: "onSelect:", forControlEvents: UIControlEvents.ValueChanged)
        
        
        // 初期化処理
        datePicker = UIDatePicker()
        datePicker!.center = self.view.center
        // 年月日の選択
        datePicker!.datePickerMode = UIDatePickerMode.Date
        
        // 年月日を指定
        let dateFormatter : NSDateFormatter = NSDateFormatter()
        dateFormatter.locale = NSLocale(localeIdentifier: "ja_JP")
        dateFormatter.dateFormat = "yyyy-MM-dd HH:mm:ss"
        let formatterDate : NSDate = dateFormatter.dateFromString("2016-12-01 19:00:00")!
        datePicker!.setDate(formatterDate, animated:false)
        
        // ピッカーの値が変わった際の処理を指定
        datePicker!.addTarget(self, action: "selectDate:", forControlEvents: UIControlEvents.ValueChanged)
        
        self.view.addSubview(datePicker!)
    }

    func selectDate(sender:UIDatePicker){
        let picker : UIDatePicker = sender
        
        // フォーマットを指定
        let dateFormatter : NSDateFormatter = NSDateFormatter()
        dateFormatter.locale = NSLocale(localeIdentifier: "ja_JP")
        dateFormatter.dateFormat = "yyyy年MM月dd日 HH時mm分"
        // 選択された日付を出力
        print(dateFormatter.stringFromDate(picker.date))
    }
    
    func onSelect(sender:UISegmentedControl){
        let seg : UISegmentedControl = sender
        
        switch(seg.selectedSegmentIndex){
            case 0 :
                datePicker!.datePickerMode = UIDatePickerMode.DateAndTime
                datePicker!.minuteInterval = 5
            
            case 1 :
                // 日付選択の形式を指定
                datePicker!.datePickerMode = UIDatePickerMode.Date
                let minDateString = "2015-08-01"
                let maxDateString = "2015-09-01"
                
                // フォーマットを指定
                let dateFormatter : NSDateFormatter = NSDateFormatter()
                dateFormatter.dateFormat = "yyyy-MM-dd"
                
                // 日付の最小値を指定
                datePicker!.minimumDate = dateFormatter.dateFromString(minDateString)
                // 日付の最大値を指定
                datePicker!.maximumDate = dateFormatter.dateFromString(maxDateString)
            
            case 2:
                // 10分間隔
                datePicker!.datePickerMode = UIDatePickerMode.Time
                datePicker!.minuteInterval = 10
            
            case 3:
                datePicker!.datePickerMode = UIDatePickerMode.CountDownTimer
                datePicker!.countDownDuration = 5*60
            
            default:
                break
        }
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
