//
//  EditTableViewController.swift
//  VC
//
//

import UIKit

class EditTableViewController: UITableViewController
{
    
    let kCellIdentifier = "CellIdentifier"
    var items: Array<String> = Array<String>()
    var editButton : UIBarButtonItem?
    
    required init(coder aDecoder: NSCoder) {
        //fatalError("init(coder:) has not been implemented")
        super.init(coder: aDecoder)!
    }
    
    override init(nibName nibNameOrNil: String?, bundle nibBundleOrNil: NSBundle?)
    {
        super.init(nibName: nibNameOrNil, bundle: nibBundleOrNil)
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.tableView = UITableView(frame: self.view.bounds, style: UITableViewStyle.Grouped)
        
        items = ["Menu1", "Menu2", "Menu3", "Menu4", "Menu5", "Menu6"]
        
        // ナビゲーションアイテムの右側に編集ボタンを設置
        editButton = UIBarButtonItem(title: "編集", style: UIBarButtonItemStyle.Plain, target: self, action: Selector("selToEdit:"))
        self.navigationItem.rightBarButtonItem = editButton
    }
    
    func selToEdit(sender:UIButton){
        // 編集可能ならば編集不可に
        if(self.tableView.editing){
            editButton!.title = "編集"
            self.setEditing(false, animated: true)
        }else{
            // 編集不可ならば編集可能に
            editButton!.title = "完了"
            self.setEditing(true, animated: true)
        }
    }
    
    // Override to support conditional editing of the table view.
    // セル単位での編集可否を指定
    override func tableView(tableView: UITableView,
        canEditRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        // Return NO if you do not want the specified item to be editable.
        // 0番目のセルは編集を許可しない
        if indexPath.row==0 { return false }
        return true
    }
    
    override func setEditing(editing: Bool, animated: Bool) {
        // テーブルの編集中はバックボタンを表示しない
        self.navigationItem.setHidesBackButton(editing, animated: animated)
        if(editing){
            let newIndexPath = NSIndexPath(forRow: items.count, inSection: 0)
            items.append("登録")
            self.tableView.insertRowsAtIndexPaths([newIndexPath], withRowAnimation: UITableViewRowAnimation.Fade)
        }else{
            let indexPath = NSIndexPath(forRow: items.count-1, inSection: 0)
            items.removeAtIndex(indexPath.row)
            self.tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: UITableViewRowAnimation.Fade)
        }
        super.setEditing(editing, animated: animated)
    }
    
    // テーブルの編集形式を指定
    override func tableView(tableView: UITableView,
        editingStyleForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCellEditingStyle
    {
        // 最後のセルは挿入
        if items.count == indexPath.row+1 {
            return UITableViewCellEditingStyle.Insert
        }
        // それ以外は削除
        else{
            return UITableViewCellEditingStyle.Delete
        }
    }
    
    // テーブルを編集
    override func tableView(tableView: UITableView,
        commitEditingStyle editingStyle: UITableViewCellEditingStyle,
        forRowAtIndexPath indexPath: NSIndexPath)
    {
        if (editingStyle == UITableViewCellEditingStyle.Delete) {
            items.removeAtIndex(indexPath.row)
            // Delete the row from the data source
            // 削除
            self.tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: UITableViewRowAnimation.Fade)
        }
        else if (editingStyle == UITableViewCellEditingStyle.Insert) {
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
            // 挿入
            items.insert("Menu7", atIndex: items.count-1)
            self.tableView.insertRowsAtIndexPaths([indexPath], withRowAnimation: UITableViewRowAnimation.Fade)
        }
    }
    
    // テーブルの編集可否を指定
    override func tableView(tableView: UITableView,
        canMoveRowAtIndexPath indexPath: NSIndexPath) -> Bool
    {
        // Return NO if you do not want the item to be re-orderable.
        // 最初のセルは移動不可
        if indexPath.row==0 { return false }
        // それ以外のセルは移動可能
        return true
    }
    
    // テーブルのセルを移動
    override func tableView(tableView: UITableView,
        moveRowAtIndexPath fromIndexPath: NSIndexPath,
        toIndexPath: NSIndexPath)
    {
        print("\(fromIndexPath.row)番地から\(toIndexPath.row)番地に移動しました")
    }
    
    override func tableView(tableView: UITableView,
        heightForRowAtIndexPath indexPath:  NSIndexPath) -> CGFloat {
            return 50
    }
    
    override func tableView(tableView: UITableView,
        numberOfRowsInSection section: Int) -> Int {
            return items.count
    }
    
    override func tableView(tableView: UITableView, cellForRowAtIndexPath
        indexPath: NSIndexPath) -> UITableViewCell {
            //テーブルのセルの生成(8)
            var cell = tableView.dequeueReusableCellWithIdentifier(
                kCellIdentifier)
            if cell == nil {
                cell = UITableViewCell(style: UITableViewCellStyle.Default,
                    reuseIdentifier: kCellIdentifier)
            }
            let cellTitle = items[indexPath.row]
            cell!.textLabel?.text = cellTitle
            return cell!
    }
    
    override func tableView(tableView: UITableView?, didSelectRowAtIndexPath indexPath:NSIndexPath) {
        /*
        var multitouchViewController = MultitouchViewController(nibName : "MultitouchViewController", bundle : nil)
        //self.navigationController.pushViewController(textFieldViewController, animated: true)
        self.navigationController?.pushViewController(multitouchViewController, animated: true)
        */
    }
    
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
}
