//
//  AutoResizeViewController.swift
//  View
//
//

import UIKit

class AutoResizeViewController: UIViewController, UIPickerViewDelegate, UIPickerViewDataSource {

    var parentView : UIView?
    var childView : UIView?
    
    var picker : UIPickerView?
    var items : Array<String>?
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        parentView = UIView(frame: CGRectMake( 0, 60, 160, 160 ))
        parentView!.backgroundColor = UIColor.blackColor()
        self.view.addSubview(parentView!)
        
        // 子要素となるラベルをひとつ追加
        childView = UIView(frame: CGRectInset( parentView!.bounds, 30, 30 ))
        childView!.backgroundColor = UIColor.orangeColor()
        parentView!.addSubview(childView!)
        
        picker = UIPickerView()
        picker!.delegate = self
        picker!.showsSelectionIndicator = true
        picker!.frame = CGRectMake(0,260,self.view.bounds.size.width,120)
        self.view.addSubview(picker!)
        
        // ピッカーのタイトルを配列で定義
        items = ["UIViewAutoresizing.None",
                    "UIViewAutoresizing.FlexibleLeftMargin",
                    "UIViewAutoresizing.FlexibleWidth",
                    "UIViewAutoresizing.FlexibleRightMargin",
                    "UIViewAutoresizing.FlexibleTopMargin",
                    "UIViewAutoresizing.FlexibleHeight",
                    "UIViewAutoresizing.FlexibleBottomMargin"]
        
        
        let button : UIButton = UIButton(type: UIButtonType.System)
        button.frame = CGRectMake(0, 0, 150, 30)
        button.center = self.view.center
        button.center.y = 440
        button.backgroundColor = UIColor.grayColor()
        button.setTitle("Button", forState: .Normal)
        button.setTitleColor(UIColor.whiteColor(), forState: .Normal)
        button.addTarget(self, action: "onPush:", forControlEvents:.TouchUpInside)
        self.view.addSubview(button)
    }

    // ボタン押下時の処理
    func onPush(sender: UIButton){
        if ( parentView!.frame.size.width == 160 ) {
            parentView!.frame = CGRectMake( 0, 60, 200, 200 )
        } else {
            parentView!.frame = CGRectMake( 0, 60, 160, 160 )
        }
    }
    
    func numberOfComponentsInPickerView(pickerView: UIPickerView) -> Int {
        return 1
    }
    
    func pickerView(pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        return items!.count
    }
    
    func pickerView(pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        return items![row] as String
    }
    
    func pickerView(pickerView: UIPickerView, viewForRow row: Int, forComponent component: Int, reusingView view: UIView?) -> UIView{
        
        var label = view as? UILabel
        
        if label == nil {
            label = UILabel(frame:CGRectMake(0.0, 0.0, pickerView.rowSizeForComponent(component).width, pickerView.rowSizeForComponent(component).height))
            
        }
        
        label!.text = items![row] as String
        label!.font = UIFont(name: "Arial Rounded MT Bold", size: 16.0)
        label!.backgroundColor = UIColor.clearColor()
        label!.textAlignment = NSTextAlignment.Center
        return label!
    }
    
    // ピッカー選択時にautoresizingMaskプロパティの値を変更
    func pickerView(pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
        switch(row){
        case 1:
            childView!.autoresizingMask = .FlexibleLeftMargin
        case 2:
            childView!.autoresizingMask = .FlexibleWidth
        case 3:
            childView!.autoresizingMask = .FlexibleRightMargin
        case 4:
            childView!.autoresizingMask = .FlexibleTopMargin
        case 5:
            childView!.autoresizingMask = .FlexibleHeight
        case 6:
            childView!.autoresizingMask = .FlexibleBottomMargin
        default:
            break
        }
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
