//
//  MapAnnotationViewController.swift
//  View
//
//

import UIKit
import MapKit

class MapAnnotationViewController: UIViewController, MKMapViewDelegate {

    @IBOutlet var mapView: MKMapView!
    
    @IBOutlet var activityIndicator: UIActivityIndicatorView!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        // 中心の緯度経度
        let location = CLLocationCoordinate2D(
            latitude: 35.710139,
            longitude: 139.810833
        )
        // 地図の上端の緯度と下端の緯度の差
        // 地図の左端の経度と右端の経度の差
        let span = MKCoordinateSpanMake(0.2, 0.2)
        
        let region = MKCoordinateRegion(center: location, span: span)
        
        // 範囲を指定
        mapView.setRegion(region, animated: true)
        
        let annotation = MKPointAnnotation()
        annotation.coordinate = location
        annotation.title = "東京スカイツリー"
        annotation.subtitle = "世界一の電波塔"
        
        // MKAnnotationプロトコルを実装したクラスをコール
        let spot : Spot = Spot(title: "東京スカイツリー", subtitle: "世界一の電波塔", coordinate: location)
        // ピンを立てる
        mapView.addAnnotation(spot)
        mapView.delegate = self
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    // 読み込み開始時
    func mapViewWillStartLoadingMap(mapView: MKMapView){
        // インジケーターを表示
        activityIndicator.startAnimating()
    }
    
    // 読み込み終了時
    func mapViewDidFinishLoadingMap(mapView: MKMapView){
        // インジケーターを停止して非表示
        activityIndicator.stopAnimating()
        activityIndicator.hidden = true
    }
    
    // エラー発生時
    func mapViewDidFailLoadingMap(mapView: MKMapView,
        withError error: NSError){
            print(error)
    }
    
    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
