//
//  MapOverlayViewController.swift
//  View
//
//

import UIKit
import MapKit

class MapOverlayViewController: UIViewController, MKMapViewDelegate {

    @IBOutlet var mapView: MKMapView!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        mapView.delegate = self
        mapView.zoomEnabled = true
        
        // 中心の緯度経度
        let location = CLLocationCoordinate2D(
            latitude: 35.703056,
            longitude: 139.58
        )
        // 地図の上端の緯度と下端の緯度の差
        // 地図の左端の経度と右端の経度の差
        let span = MKCoordinateSpanMake(0.005, 0.005)
        
        let region = MKCoordinateRegion(center: location, span: span)
        
        // 範囲を指定
        mapView.setRegion(region, animated: true)
        
        // 35.703056, 139.58を中心に半径100mの円形オーバーレイを定義
        let clocation : CLLocationCoordinate2D = CLLocationCoordinate2DMake(35.703056, 139.58)
        let circleOverlay : MKCircle = MKCircle(centerCoordinate: clocation, radius: 100)
        
        // 地図にセット
        mapView.addOverlay(circleOverlay)
    }
    
    // オーバーレイを表示
    func mapView(mapView: MKMapView,
        rendererForOverlay overlay: MKOverlay) -> MKOverlayRenderer{
        
        // 円形オーバーレイ描画オブジェクトを生成
        let renderer : MKCircleRenderer = MKCircleRenderer(circle: overlay as! MKCircle)
        // 縁、色を青、透明度を0.3で描画
        renderer.lineWidth = 1
        renderer.strokeColor = UIColor.blueColor()
        renderer.fillColor = UIColor.blueColor()
        renderer.alpha = 0.3
        return renderer
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
