//
//  MapViewController.swift
//  View
//
//

import UIKit
import MapKit

class MapViewController: UIViewController, MKMapViewDelegate {

    @IBOutlet var mapView: MKMapView!
    
    @IBOutlet var activityIndicator: UIActivityIndicatorView!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        mapView.delegate = self
        // 現在位置を表示
        mapView.showsUserLocation = true
        mapView.zoomEnabled = true
        
        // 中心の緯度経度
        let location = CLLocationCoordinate2D(
            //latitude: 35.703056,
            //longitude: 139.58
            latitude: 35.681111,
            longitude: 139.766667
        )
        // 地図の上端の緯度と下端の緯度の差
        // 地図の左端の経度と右端の経度の差
        let span = MKCoordinateSpanMake(0.005, 0.005)
        
        let region = MKCoordinateRegion(center: location, span: span)
        
        // 範囲を指定
        mapView.setRegion(region, animated: true)
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    // 地図の種類をボタンで指定
    @IBAction func onStandard(sender: AnyObject) {
        // 標準の地図
        mapView.mapType = MKMapType.Standard
    }
    
    @IBAction func onSatellite(sender: AnyObject) {
        // 航空写真
        mapView.mapType = MKMapType.Satellite
    }

    @IBAction func onHybrid(sender: AnyObject) {
        // 標準の地図と航空写真
        mapView.mapType = MKMapType.Hybrid
    }
    
    @IBAction func onSatelliteFlyover(sender: AnyObject) {
        // 航空写真の3D
        mapView.mapType = MKMapType.SatelliteFlyover
        setMapCamera()
    }
    
    @IBAction func onHybridFlyover(sender: AnyObject) {
        // 航空写真の3Dと標準の地図
        mapView.mapType = MKMapType.HybridFlyover
        setMapCamera()
    }
    
    // カメラの指定
    func setMapCamera() {
        mapView.camera.pitch = 40.0     // 傾斜
        mapView.camera.heading = 100    // 高さ(m)
    }
    
    // 読み込み開始時
    func mapViewWillStartLoadingMap(mapView: MKMapView){
        // インジケーターを表示
        activityIndicator.startAnimating()
    }
    
    // 読み込み終了時
    func mapViewDidFinishLoadingMap(mapView: MKMapView){
        // インジケーターを停止して非表示
        activityIndicator.stopAnimating()
        activityIndicator.hidden = true
    }
    
    // エラー発生時
    func mapViewDidFailLoadingMap(mapView: MKMapView,
        withError error: NSError){
            print(error)
    }
    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */
}
